Test coverage report: frequently.views

# frequently.views: 5 total statements, 100.0% covered

Generated: Fri 2012-09-28 15:02 CEST

Source file: /Users/martin/Repos/django-frequently/frequently/views.py

Stats: 4 executed, 0 missed, 1 excluded, 7 ignored

1. `"""`
2. `Views for the ``django-frequently`` application.`
3. ``
4. `"""`
5. `from django.views.generic import TemplateView`
6. ``
7. ``
8. `class HomeView(TemplateView):`
9. `template_name = 'frequently/home.html'`
10. ``
11. `def dispatch(self, *args, **kwargs):`
12. `return super(HomeView, self).dispatch(*args, **kwargs)`